diplomat_buffer_write_len

Function diplomat_buffer_write_len 

#[unsafe(no_mangle)]
pub extern "C" fn diplomat_buffer_write_len( this: &DiplomatWrite, ) -> usize
Gets the length in bytes of the content written to the writable.

Returns 0 if there was an allocation error during the write construction.

Safety