#[unsafe(no_mangle)]pub extern "C" fn diplomat_buffer_write_len(
this: &DiplomatWrite,
) -> usizeExpand description
Gets the length in bytes of the content written to the writable.
Returns 0 if there was an allocation error during the write construction.
Safety
thismust be a pointer to a validDiplomatWriteconstructed bydiplomat_buffer_write_create().